@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0300';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -43,6 +43,25 @@ sub _build__scale {
     return \@with_octaves;
 }
 
+has _enharmonics => (
+    is        => 'lazy',
+    init_args => undef,
+);
+
+sub _build__enharmonics {
+  my ($self) = @_;
+  my %enharmonics = (
+      'C#' => 'Db',
+      'D#' => 'Eb',
+      'E#' => 'F',
+      'F#' => 'Gb',
+      'G#' => 'Ab',
+      'A#' => 'Bb',
+      'B#' => 'C',
+  );
+  return { %enharmonics, reverse %enharmonics }
+}
+
 
 has verbose => (
     is      => 'ro',
@@ -57,7 +76,7 @@ sub transpose {
     my @transposed;
 
     for my $n (@$notes) {
-        my $i = first_index { $_ eq $n } @{ $self->_scale };
+        (my $i, $n) = $self->_find_pitch($n);
         push @transposed, $i == -1 ? undef : $self->_scale->[ $i + $offset ];
     }
     print 'Transposed: ', ddc(\@transposed) if $self->verbose;
@@ -65,6 +84,17 @@ sub transpose {
     return \@transposed;
 }
 
+sub _find_pitch {
+    my ($self, $pitch) = @_;
+    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    if ($i == -1) {
+        my $enharmonics = $self->_enharmonics;
+        $pitch =~ s/^([A-G][#b]?)(\d+)$/$enharmonics->{$1}$2/;
+        $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    }
+    return $i, $pitch;
+}
+
 1;
 
 __END__
@@ -79,7 +109,7 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
